{% load i18n %}

<div class="navbar nav-profile">
    <div class="navbar-inner">
        <div class="container">

            <!-- .navbar-btn is used as the toggle for collapsed navbar content -->
            <a class="btn navbar-btn" data-toggle="collapse" data-target=".profile-collapse">
                <span class="icon-bar"></span>
                <span class="icon-bar"></span>
                <span class="icon-bar"></span>
            </a>

            <span class="brand visible-sm" href="#">{{ page_title }}</span>

            <div class="navbar-collapse profile-collapse">
                <ul class="nav nav-tabs">
                    {% block standard_tabs %}
                        {% include 'oscar/customer/partials/standard_tabs.html' %}
                    {% endblock %}
                    {% block extra_tabs %}
                    {% endblock %}
                </ul>
            </div>
        </div>
    </div>
</div>
