{% extends 'oscar/dashboard/layout.html' %}
{% load i18n %}
{% load currency_filters %}

{% block title %}
    {% trans "Edit weight band" %} |
    {{ band.method.name }} |
    {{ block.super }}
{% endblock %}

{% block breadcrumbs %}
    <ul class="breadcrumb">
        <li>
            <a href="{% url 'dashboard:index' %}">{% trans "Dashboard" %}</a>
        </li>
        <li>
            <a href="{% url 'dashboard:shipping-method-list' %}">{% trans "Shipping methods" %}</a>
        </li>
        <li>
            {{ band.method.name }}
        </li>
        <li class="active">{% trans "Edit weight band" %}</li>
    </ul>
{% endblock %}

{% block headertext %}
    {% trans "Edit weight band" %}
{% endblock %}

{% block dashboard_content %}
    <div class="well">
        <form method="post" class="form-stacked">
            {% csrf_token %}
            {% include "oscar/dashboard/partials/form_fields.html" with form=form %}
            {% block form_actions %}
                <div class="form-actions">
                    <button class="btn btn-primary btn-lg" type="submit" data-loading-text="{% trans 'Saving...' %}">{% trans "Save" %}</button> {% trans "or" %}
                    <a href="{% url 'dashboard:shipping-method-list' %}">{% trans "cancel" %}</a>
                </div>
            {% endblock form_actions %}
        </form>
    </div>
{% endblock %}
