// OSC VARIABLES
// --------------------------------------------------

// Page width
@oscarpagewidth: 1280px;
// Image height
@imagecontainerheight: 165px;

@form-actions-bg-color: #f5f5f5;
@form-actions-border-color: #e5e5e5;

// Custom colors
@white: #fff;
@black: #000;
