{% extends "oscar/layout.html" %}

{% comment %}
Keep the same header and footer as the standard layout template but override the 
main content area to split it into a sidebar and a content block
{% endcomment %}
{% block content_wrapper %}
<div class="container-fluid page">
    <div class="page_inner">
        {% block breadcrumbs %}{% endblock %}
        <div class="row">

            <aside class="sidebar col-sm-4 col-md-3">
                {% block column_left %}{% endblock %}
            </aside>

            <div class="col-sm-8 col-md-9">
                {% block header %}
                <div class="page-header action">
                    <h1>{% block headertext %}{% endblock %}</h1>
                </div>
                {% endblock %}

                {% include "oscar/partials/alert_messages.html" %}

                {% block content %}{% endblock %}
            </div>

        </div><!-- /row -->
    </div><!-- /page_inner -->
</div><!-- /container-fluid -->
{% endblock %}
