{% load i18n %}
{% load display_tags %}

<li{% if active_tab == 'profile' %} class="active"{% endif %}>
    <a href="{% url 'customer:profile-view' %}">{% trans "Profile" %}</a>
</li>
<li{% if active_tab == 'orders' %} class="active"{% endif %}>
    <a href="{% url 'customer:order-list' %}">{% trans "Order History" %}</a>
</li>
<li{% if active_tab == 'addresses' %} class="active"{% endif %}>
    <a href="{% url 'customer:address-list' %}">{% trans "Address Book" %}</a>
</li>
<li{% if active_tab == 'emails' %} class="active"{% endif %}>
    <a href="{% url 'customer:email-list' %}">{% trans "Email History" %}</a>
</li>
<li{% if active_tab == 'alerts' %} class="active"{% endif %}>
    <a href="{% url 'customer:alerts-list' %}">{% trans "Product Alerts" %}</a>
</li>
<li{% if active_tab == 'notifications' %} class="active"{% endif %}>
    <a href="{% url 'customer:notifications-inbox' %}">{% trans "Notifications" %}</a>
</li>
{% iffeature 'wishlists' %}
    <li{% if active_tab == 'wishlists' %} class="active"{% endif %}>
        <a href="{% url 'customer:wishlists-list' %}">{% trans "Wish Lists" %}</a>
    </li>
{% endiffeature %}