// Core variables and mixins
@import "bootstrap3/variables.less";
@import "bootstrap3/mixins.less";

// Oscar variables
@import "page/mixins.less"; // Kept separate for bootstrap updates - but should be imported into bootstap mixins.

// Reset and dependencies
@import "bootstrap3/normalize.less";
@import "bootstrap3/print.less";
@import "bootstrap3/glyphicons.less";

// Core CSS
@import "bootstrap3/scaffolding.less";
@import "bootstrap3/type.less";
@import "bootstrap3/code.less";
@import "bootstrap3/grid.less";
@import "bootstrap3/tables.less";
@import "bootstrap3/forms.less";
@import "bootstrap3/buttons.less";

// Components
@import "bootstrap3/component-animations.less";
@import "bootstrap3/dropdowns.less";
@import "bootstrap3/button-groups.less";
@import "bootstrap3/input-groups.less";
@import "bootstrap3/navs.less";
@import "bootstrap3/navbar.less";
@import "bootstrap3/breadcrumbs.less";
@import "bootstrap3/pagination.less";
@import "bootstrap3/pager.less";
@import "bootstrap3/labels.less";
@import "bootstrap3/badges.less";
@import "bootstrap3/jumbotron.less";
@import "bootstrap3/thumbnails.less";
@import "bootstrap3/alerts.less";
@import "page/alerts.less";
@import "bootstrap3/progress-bars.less";
@import "bootstrap3/media.less";
@import "bootstrap3/list-group.less";
@import "bootstrap3/panels.less";
@import "bootstrap3/responsive-embed.less";
@import "bootstrap3/wells.less";
@import "bootstrap3/close.less";

// Components: Icons / Fonts
@import "font-awesome/font-awesome.less"; // Replaced sprites with font-awesome

// Components w/ JavaScript
@import "bootstrap3/modals.less";
@import "bootstrap3/tooltip.less";
@import "bootstrap3/popovers.less";
@import "bootstrap3/carousel.less";

// Oscar: Unique
@import "page/layout.less";
@import "page/type.less";
@import "page/forms.less";
@import "page/header.less";
@import "page/product_lists.less";
@import "page/product_page.less";
@import "page/reviews.less";
@import "page/checkout.less";
@import "page/wells.less";
@import "page/plugins.less";

// Utility classes
@import "bootstrap3/utilities.less";
@import "bootstrap3/responsive-utilities.less";
