// Core variables and mixins
@import "bootstrap3/variables.less";
@import "bootstrap3/mixins.less";

// Reset and dependencies
@import "bootstrap3/normalize.less";
@import "bootstrap3/print.less";

// Core CSS
@import "bootstrap3/scaffolding.less";
@import "bootstrap3/type.less";
@import "bootstrap3/code.less";
@import "bootstrap3/grid.less";
@import "bootstrap3/tables.less";
@import "bootstrap3/forms.less";
@import "bootstrap3/buttons.less";

// Components
@import "bootstrap3/component-animations.less";
@import "bootstrap3/dropdowns.less";
@import "bootstrap3/button-groups.less";
@import "bootstrap3/input-groups.less";
@import "bootstrap3/navs.less";
@import "bootstrap3/navbar.less";
@import "bootstrap3/breadcrumbs.less";
@import "bootstrap3/pagination.less";
@import "bootstrap3/pager.less";
@import "bootstrap3/labels.less";
@import "bootstrap3/badges.less";
@import "bootstrap3/jumbotron.less";
@import "bootstrap3/thumbnails.less";
@import "bootstrap3/alerts.less";
@import "bootstrap3/progress-bars.less";
@import "bootstrap3/media.less";
@import "bootstrap3/list-group.less";
@import "bootstrap3/panels.less";
@import "bootstrap3/responsive-embed.less";
@import "bootstrap3/wells.less";
@import "bootstrap3/close.less";

// Components w/ JavaScript
@import "bootstrap3/modals.less";

// Utility classes
@import "bootstrap3/utilities.less";
@import "bootstrap3/responsive-utilities.less";

// Core variables and mixins separate from frontend variables and mixins
@import "dashboard/variables.less";
@import "dashboard/mixins.less";
@import "dashboard/alerts.less";
@import "dashboard/base.less";
@import "dashboard/buttons.less";
@import "dashboard/datetimepicker.less";
@import "dashboard/navbar.less";
@import "dashboard/forms.less";
@import "dashboard/tables.less";
@import "dashboard/login.less";
@import "dashboard/index.less";
@import "dashboard/catalogue.less";
@import "dashboard/order.less";
@import "dashboard/sortable.less";

// Components: Icons / Fonts
@import "font-awesome/font-awesome.less"; // Replaced sprites with font-awesome
