.datetimepicker .glyphicon {
  font-family: FontAwesome;
  font-weight: normal;
  font-style: normal;
  text-decoration: inherit;
  -webkit-font-smoothing: antialiased;
  *margin-right: .3em;
}
.datetimepicker .glyphicon.glyphicon-arrow-left:before {
  content: "\f060";
}
.datetimepicker .glyphicon.glyphicon-arrow-right:before {
  content: "\f061";
}